<?php
/**
*  @author		@mario forum.prestashop.pl 2012
*  @license		http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
*/

if (!defined('_PS_VERSION_'))
	exit;

class ReCaptcha extends Module
{
	private  $protectedPages = array('contact-form', 'product','modules/sendtoafriend/sendtoafriend-form');
	private  $pageName;
	private  $hook = 'beforeInit';

	function __construct()
	{
		$this->name = 'recaptcha';
		$this->tab = 'front_office_features';
		$this->version = '1.0';
		$this->author = '@mario forum.prestashop.pl';
		$this->need_instance = 0;
		parent::__construct();

		$this->displayName = 'ReCaptcha';
		$this->description = $this->l('Anti-Spam Forms Protector.');
		$this->pageName = substr(preg_replace('/\.php$/', '', $_SERVER['PHP_SELF']), strlen(trim(__PS_BASE_URI__)));
		$this->confirmUninstall = $this->l('Are you sure that you want to uninstall ReCaptcha module?');
		if (Configuration::get('RECAPTCHA_PRIVATE_KEY') == '')
				$this->warning = $this->l('ReCaptcha keys warning.');

	}

	public function install()
	{
		if(!Hook::get($this->hook))
			if (!Db::getInstance()->AutoExecute(_DB_PREFIX_.'hook', array('name' => $this->hook, 'title' => 'On before Init in Controllers', 'description' => 'Get exec modules before FrontController init', 'position' => 0), 'INSERT'))
					return false;

		return (parent::install()
			AND $this->registerHook($this->hook) 
			AND $this->registerHook('footer')
			AND Configuration::updateValue('RECAPTCHA_PUBLIC_KEY', '')
			AND Configuration::updateValue('RECAPTCHA_PRIVATE_KEY', '')
			AND Configuration::updateValue('RECAPTCHA_THEME', 'red'));
	}

	public function uninstall()
	{
		return (parent::uninstall()
			AND Configuration::deleteByName('RECAPTCHA_PUBLIC_KEY')
			AND Configuration::deleteByName('RECAPTCHA_PRIVATE_KEY')
			AND Configuration::deleteByName('RECAPTCHA_THEME'));
	}

	private function pageIsToProtect()
	{
		if (in_array($this->pageName, $this->protectedPages))
				return true;
		return false;
	}

	public function hookBeforeInit($params)
	{
		if ($this->pageIsToProtect() AND (Tools::isSubmit('submitMessage') OR Tools::isSubmit('submitAddtoafriend')))
		{
			if(!isset($_SESSION))
					session_start();

			if(!isset($_SESSION['recaptcha']) OR $_SESSION['recaptcha'] != md5($_POST['recaptcha_response_field']._COOKIE_IV_))
			{
				if(isset($_POST['submitMessage']))
						unset($_POST['submitMessage']);
				if(isset($_POST['email']))
						unset($_POST['email']);
			}    

			if(isset($_SESSION['recaptcha']))
					unset($_SESSION['recaptcha']);
		}
	}

	public function hookFooter($params)
	{
		global $smarty;

		if (!$this->pageIsToProtect())
				return;

		if($this->pageName == 'product' AND !$this->isInstalled('productcomments'))
				return;

		if($this->pageName == 'modules/sendtoafriend/sendtoafriend-form' AND !$this->isInstalled('sendtoafriend'))
				return;

		$error = null;
		$smarty->assign(array(
			'publicKey' => Configuration::get('RECAPTCHA_PUBLIC_KEY'),
			'reCaptchaTheme' => Configuration::get('RECAPTCHA_THEME'),
			'statusOK' => $this->l('Sending ...'),
			'statusError' => $this->l('Security code you entered did not match. Please try again.')));

		return $this->display(__FILE__, 'recaptcha.tpl');

	}

	public function getContent()
	{
		$this->_html = '<h2>'.$this->displayName.'</h2>';
		$this->_postProcess();
		$this->_displayFormReCaptcha();
		return $this->_html;
	}

	private function _postProcess()
	{
		if (Tools::isSubmit('submitReCaptcha'))
		{
			Configuration::updateValue('RECAPTCHA_PUBLIC_KEY', pSQL(trim(Tools::getValue('public_key'))));
			Configuration::updateValue('RECAPTCHA_PRIVATE_KEY', pSQL(trim(Tools::getValue('private_key'))));
			Configuration::updateValue('RECAPTCHA_THEME', pSQL(Tools::getValue('theme')));
			$this->_html .= '<div class="conf confirm"><img src="../img/admin/ok.gif" alt="'.$this->l('Confirmation').'" />'.$this->l('Settings updated').'</div>';
		}
	}

	private function _displayFormReCaptcha()
	{
		$this->_html .= '
		<b>'.$this->l('Now your Contact, Productcomments and Sendtoafriend forms protected.').'</b><br /><br />';

		$this->_html .= '
		<fieldset class="width2">
			<legend><img src="../img/admin/cog.gif" alt="" />'.$this->l('ReCaptcha keys').'</legend>
				<p style="margin-bottom: 20px;">'.$this->l('Get your keys from Google developer website.').'<br />
				<br /><a href="https://www.google.com/recaptcha/admin/create" target="_blank">https://www.google.com/recaptcha/admin/create</a>
				<form action="'.$this->_baseUrl.'" method="post" name="recaptcha_form">
				<label>'.$this->l('Public key value').'</label>
				<div class="margin-form">
					<input value="'.Configuration::get('RECAPTCHA_PUBLIC_KEY').'" type="text" class="text" name="public_key" style="width: 300px;" />
				</div>
				<div class="clear">&nbsp;</div>
				<label>'.$this->l('Private key value').'</label>
				<div class="margin-form">
					<input value="'.Configuration::get('RECAPTCHA_PRIVATE_KEY').'" type="text" class="text" name="private_key" style="width: 300px;" />
				</div>
				<div class="clear">&nbsp;</div>
				<label>'.$this->l('Theme').'</label>
				<div class="margin-form">
					<select name="theme">';
					$themes = array('blackglass', 'clean', 'red', 'white');
					foreach ($themes AS $theme)
					$this->_html.= '<option value="'.$theme.'" '.($theme == Configuration::get('RECAPTCHA_THEME') ? 'selected="selected"' : '').'>'.$theme.'</option>';
				$this->_html .= '</select>
				</div>
				<div class="clear"></div>
				<div class="margin-form clear">
					<input type="submit" name="submitReCaptcha" value="'.$this->l('Save').'" class="button" />
				</div>
				</form>
		</fieldset><br />';
	}
}